## Copyright (C) 2004 Eric Chassande-Mottin
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

function [tfr,t,f] = dwv(x,t,fs);
%DWV	Wigner-Ville time-frequency distribution as defined by Chassande/Pai
%       Uses the "interlaced" signal.
%	[TFR,T,F]=DWV(X,T,FS) computes the Wigner-Ville distribution
%	of a discrete-time signal X, 
% 
%	X     : signal
%	T     : time instant(s)          (default : 1:length(X)).
%	FS    : sampling frequency       (default : 1).
%	TFR   : time-frequency representation.
%	F     : vector of normalized frequencies.

if (nargin == 0),
 error('At least one parameter required');
end;

[xrow,xcol] = size(x);
N=xrow;

if (nargin == 1),
  t=1:xrow; fs=1; trace=0;
elseif (nargin == 2),
  fs=1; trace=0;
elseif (nargin ==3),
  trace=0;
end;

[trow,tcol] = size(t);
if (xcol==0)|(xcol>1),
  error('X must have one column');
elseif (trow~=1),
  error('T must only have one row'); 
elseif (2^nextpow2(N)~=N),
  error('N must be a power of two');
end; 

% -- create the interlaced signal and corresponding time vector
N2=2*N;
x3=zeros(N2,1);
x3(1:2:N2-1)=x;
x3(2:2:N2)=x;
t3=2*t-1;

% -- compute lacf
tfr=lacf(x3,t3);

% -- make FFT
tfr= fft(tfr)/fs; 
tfr=real(tfr);

if (nargout==3),
 f=fs*(0:N2-1)'/N2;
end;

