## Copyright (C) 1998, 1999  Boston University
## Copyright (C) 1997, 1998  Ecole Normale Superieure de Lyon
## Copyright (C) 1997  The Regents of the University of Michigan
## All Rights Reserved
## 
## Jeffrey O'Neill <jeffo@bu.edu>
## 8 St. Mary's Street
## Boston, MA 02135
## 
## This program is free software; you can redistribute it and/or
## modify it under the terms of the GNU General Public License
## as published by the Free Software Foundation; either version 2
## of the License, or (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

function tfd = dwv2(x)
% wigner4 -- Compute samples of the type IV Wigner distribution.
%
%  Usage
%    tfd = dwv2(x)
%
%  Inputs
%    x     signal vector, must have an odd length
%
%  Outputs
%    tfd  matrix containing the Wigner distribution of signal x.  If x 
%         has length N, then tfd will be N by N. (optional)
%
% If no output arguments are specified, then the Wigner distribution is 
% displayed using ptfd(tfd, t, f).  Note that the Wigner distribution does not
% exist for type IV signals with an even length.  However, qwigner4 provides
% a reasonable approximation.  This was first derived by M.S. Richman, T.W.
% Parks, and R.G. Shenoy (http://cam.cornell.edu/richman)

% input/output slightly changed by Eric Chassande-Mottin, ecm@obs-nice.fr
% Tue Feb  3 18:45:40 MET 2004
% and changed function name, Eric Chassande-Mottin. Sat Feb 21 14:42:48 GMT 2004

% specify defaults
x = x(:);
N = length(x);
if (floor(N/2) == N/2)
  error('x must have an odd length.');
end

acf = zeros(N);
acf(1,:) = (x.*conj(x)).';
for tau = 2:2:(N+1)/2,
  acf(tau,:) = (conj(circ(x, (N+tau-1)/2)).*circ(x, (N-tau+1)/2)).';
  acf(N-tau+2,:) = conj(acf(tau,:));
  acf(tau+1,:) = (conj(circ(x, tau/2)).*circ(x, -tau/2)).';
  acf(N-tau+1,:) = conj(acf(tau+1,:));
end

tfd = real(fft(acf));
