## Copyright (C) 2004 Eric Chassande-Mottin
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

% Gaussian logons, comparison of various WV distributions

clear;

% -- init
debug=0;              % make plot with octave yes=0, no=1

% -- signal

N=128; l=ceil(N/6);
h=zeros(2*l+1,1); t=(-l:l)';
h=exp(-4.6*t.^2/l^2);

n1=N/4; n2=N/2; n3=3*N/4;
f1=1/8; f2=3/8;
x=zeros(N,1);
x(n1+t)=x(n1+t)+h.*cos(2*pi*f1*t); % logon 1
x(n2+t)=x(n2+t)+h.*cos(2*pi*f2*t); % logon 2
x(n3+t)=x(n3+t)+h.*cos(2*pi*f1*t); % logon 3

N1=N-1;
x1=x(1:N1);x1=x1/norm(x1);
N2=N;
x2=x;x2=x2/norm(x2);

% -- compute tfr
tfr0=dwv0(x2); % Claasen/Mecklenbrauker

tfr=dwv(x2);   % Chassande/Pai

tfr1=dwv1(x2); % Peyrin/Prost

tfr2=dwv2(x1); % Richman et al./O'Neill et al.

% -- make plots

if (debug==0)  
  multiplot(1,2);
  gset nokey;
  
  subplot(2,2,1);
  contour(tfr0',[.25 -.25]);
  eval(sprintf('gset xrange [0:%d];',N2));
  eval(sprintf('gset yrange [0:%d];',2*N2));
  xlabel('time');
  ylabel('frequency');
  title('(MC)');
  
  subplot(2,2,2);
  contour(tfr',[.25 -.25]);
  eval(sprintf('gset xrange [0:%d];',N2));
  eval(sprintf('gset yrange [0:%d];',2*N2));
  xlabel('time');
  ylabel('frequency');
  title('(WV)');
  
  subplot(2,2,3);
  contour(tfr1',[.25 -.25]);
  eval(sprintf('gset xrange [0:%d];',2*N2));
  eval(sprintf('gset yrange [0:%d];',2*N2));
  xlabel('time');
  ylabel('frequency');
  title('(PP)');

  subplot(2,2,4);
  contour(tfr2',[.25 -.25]);
  eval(sprintf('gset xrange [0:%d];',N1));
  eval(sprintf('gset yrange [0:%d];',N1));
  xlabel('time');
  ylabel('frequency');
  title('(RO)');

% -- relax
  oneplot();
  gset autoscale x
  gset autoscale y
  gset term x11
  
end;

save -mat-binary other.mat tfr*

printf("wrote other.mat\n now, run the script other_fig_plot.m to make the figure\n");


